@@ -7,7 +7,8 @@
 #include "maintextjobtest.h"
 
 #include <QStandardPaths>
-#include <QTextCodec>
+// #include <QTextCodec>
+#include <QStringDecoder>
 
 #include <QDebug>
 #include <QTest>
@@ -25,15 +26,12 @@ using namespace KMime;
 
 #include <KActionCollection>
 
-//#include <kpimtextedit/textedit.h>
-
 using namespace MessageComposer;
 
 QTEST_MAIN(MainTextJobTest)
 
 void MainTextJobTest::initTestCase()
 {
-    qputenv("KDE_FORK_SLAVES", "yes"); // To avoid a runtime dependency on klauncher
     QStandardPaths::setTestModeEnabled(true);
 }
 
@@ -41,12 +39,12 @@ void MainTextJobTest::testPlainText()
 {
     auto composer = Composer();
     composer.globalPart()->setGuiEnabled(false);
-    QVector<QByteArray> charsets;
+    QList<QByteArray> charsets;
     charsets << "us-ascii"
              << "utf-8";
     composer.globalPart()->setCharsets(charsets);
     auto textPart = new TextPart;
-    QString data = QStringLiteral("they said their nevers they slept their dream");
+    QString data = QStringLiteral("they said their never they slept their dream");
     textPart->setWrappedPlainText(data);
     auto mjob = new MainTextJob(textPart, &composer);
     QVERIFY(mjob->exec());
@@ -67,7 +65,7 @@ void MainTextJobTest::testWrappingErrors()
         composer.globalPart()->setGuiEnabled(false);
         composer.globalPart()->setFallbackCharsetEnabled(true);
         auto textPart = new TextPart;
-        QString data = QStringLiteral("they said their nevers they slept their dream");
+        QString data = QStringLiteral("they said their never they slept their dream");
         textPart->setWordWrappingEnabled(false);
         textPart->setWrappedPlainText(data);
         auto mjob = new MainTextJob(textPart, &composer);
@@ -81,7 +79,7 @@ void MainTextJobTest::testWrappingErrors()
         composer.globalPart()->setFallbackCharsetEnabled(true);
         auto textPart = new TextPart;
         textPart->setWordWrappingEnabled(true);
-        QString data = QStringLiteral("they said their nevers they slept their dream");
+        QString data = QStringLiteral("they said their never they slept their dream");
         textPart->setCleanPlainText(data);
         auto mjob = new MainTextJob(textPart, &composer);
         QVERIFY(!mjob->exec()); // error: UseWrapping but given only clean text
@@ -95,7 +93,7 @@ void MainTextJobTest::testCustomCharset()
     auto composer = Composer();
     composer.globalPart()->setGuiEnabled(false);
     QByteArray charset("iso-8859-2");
-    composer.globalPart()->setCharsets(QVector<QByteArray>() << charset);
+    composer.globalPart()->setCharsets(QList<QByteArray>() << charset);
     auto textPart = new TextPart;
     QString data = QStringLiteral("şi el o să se-nchidă cu o frunză de pelin");
     textPart->setWrappedPlainText(data);
@@ -108,9 +106,15 @@ void MainTextJobTest::testCustomCharset()
     QCOMPARE(result->contentType()->mimeType(), QByteArray("text/plain"));
     QCOMPARE(result->contentType()->charset(), charset);
     QByteArray outData = result->body();
+#if 0 // Remove when we remove all QTextCodec support
     QTextCodec *codec = QTextCodec::codecForName(charset);
     QVERIFY(codec);
     QCOMPARE(codec->toUnicode(outData), data);
+#endif
+    QStringDecoder dec(charset.constData());
+    QVERIFY(dec.isValid());
+    QCOMPARE(dec.decode(outData), data);
+
     delete textPart;
 }
 
@@ -135,7 +139,7 @@ void MainTextJobTest::testBadCharset()
     auto composer = Composer();
     composer.globalPart()->setGuiEnabled(false);
     QByteArray charset("us-ascii"); // Cannot handle Romanian chars.
-    composer.globalPart()->setCharsets(QVector<QByteArray>() << charset);
+    composer.globalPart()->setCharsets(QList<QByteArray>() << charset);
     auto textPart = new TextPart;
     QString data = QStringLiteral("el a plâns peste ţară cu lacrima limbii noastre");
     textPart->setWrappedPlainText(data);
@@ -310,3 +314,5 @@ void MainTextJobTest::testHtmlWithImages()
     delete textPart;
     delete composer;
 }
+
+#include "moc_maintextjobtest.cpp"
