@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SINGLEPARTJOBTEST_H
-#define SINGLEPARTJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -20,5 +19,3 @@ private Q_SLOTS:
     void testContentType();
     void testContentTransferEncoding();
 };
-
-#endif
