@@ -38,9 +38,7 @@ AttachmentJob::AttachmentJob(AttachmentPart::Ptr part, QObject *parent)
     d->part = part;
 }
 
-AttachmentJob::~AttachmentJob()
-{
-}
+AttachmentJob::~AttachmentJob() = default;
 
 AttachmentPart::Ptr AttachmentJob::attachmentPart() const
 {
@@ -129,3 +127,5 @@ void AttachmentJob::process()
     d->resultContent = d->subjobContents.constFirst();
     emitResult();
 }
+
+#include "moc_attachmentjob.cpp"
