@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECORE_NODEHELPER_H
-#define MESSAGECORE_NODEHELPER_H
+#pragma once
 
 #include "messagecore_export.h"
 
@@ -45,5 +44,3 @@ MESSAGECORE_EXPORT KMime::Content *next(KMime::Content *node, bool allowChildren
 MESSAGECORE_EXPORT KMime::Content *firstChild(const KMime::Content *node);
 }
 }
-
-#endif
