@@ -9,25 +9,17 @@
 #include "core/manager.h"
 
 #include "core/aggregation.h"
-#include "core/model.h"
-#include "core/model_p.h"
 #include "core/storagemodelbase.h"
 #include "core/theme.h"
 #include "core/view.h"
 #include "core/widgetbase.h"
 #include "messagelistsettings.h"
 
-#include "utils/configureaggregationsdialog.h"
-#include "utils/configureaggregationsdialog_p.h"
-#include "utils/configurethemesdialog.h"
-#include "utils/configurethemesdialog_p.h"
-
 #include "MessageCore/MessageCoreSettings"
 
-#include "messagelistutil.h"
 #include "messagelistutil_p.h"
 
-#include <kmime/kmime_dateformatter.h> // kdepimlibs
+#include <KMime/DateFormatter> // kdepimlibs
 
 #include "messagelist_debug.h"
 #include <KConfig>
@@ -39,13 +31,11 @@ Manager *Manager::mInstance = nullptr;
 
 Manager::Manager()
     : QObject()
+    , mDateFormatter(new KMime::DateFormatter())
+    , mCachedLocalizedUnknownText(i18nc("Unknown date", "Unknown"))
 {
     mInstance = this;
 
-    mDateFormatter = new KMime::DateFormatter();
-
-    mCachedLocalizedUnknownText = i18nc("Unknown date", "Unknown");
-
     loadConfiguration();
     connect(MessageListSettings::self(), &MessageListSettings::configChanged, this, &Manager::reloadGlobalConfiguration);
     connect(MessageCore::MessageCoreSettings::self(), &MessageCore::MessageCoreSettings::configChanged, this, &Manager::reloadGlobalConfiguration);
@@ -153,6 +143,7 @@ void Manager::saveAggregationForStorageModel(const QString &modelId, const QStri
     if (!storageUsesPrivateAggregation) {
         conf.writeEntry(QStringLiteral("DefaultSet"), id);
     }
+    conf.sync();
 }
 
 const Aggregation *Manager::aggregationForStorageModel(const Akonadi::Collection &col, bool *storageUsesPrivateAggregation)
@@ -435,6 +426,7 @@ void Manager::saveThemeForStorageModel(const QString &storageModelIndex, const Q
     if (!storageUsesPrivateTheme) {
         conf.writeEntry(QStringLiteral("DefaultSet"), id);
     }
+    conf.sync();
 }
 
 const Theme *Manager::themeForStorageModel(const Akonadi::Collection &col, bool *storageUsesPrivateTheme)
@@ -519,17 +511,17 @@ static Theme::Column *add_theme_simple_text_column(Theme *s,
     c->addMessageRow(r);
 
     if (addGroupHeaderItem) {
-        auto r = new Theme::Row();
+        auto row = new Theme::Row();
 
-        auto i = new Theme::ContentItem(type);
+        auto iRow = new Theme::ContentItem(type);
 
         if (alignRight) {
-            r->addRightItem(i);
+            row->addRightItem(iRow);
         } else {
-            r->addLeftItem(i);
+            row->addLeftItem(iRow);
         }
 
-        c->addGroupHeaderRow(r);
+        c->addGroupHeaderRow(row);
     }
 
     s->addColumn(c);
@@ -875,7 +867,7 @@ void Manager::loadConfiguration()
     {
         // load Aggregations
 
-        KConfigGroup conf(MessageListSettings::self()->config(), "MessageListView::Aggregations");
+        KConfigGroup conf(MessageListSettings::self()->config(), QStringLiteral("MessageListView::Aggregations"));
 
         mAggregations.clear();
 
@@ -907,7 +899,7 @@ void Manager::loadConfiguration()
     {
         // load Themes
 
-        KConfigGroup conf(MessageListSettings::self()->config(), "MessageListView::Themes");
+        KConfigGroup conf(MessageListSettings::self()->config(), QStringLiteral("MessageListView::Themes"));
 
         mThemes.clear();
 
@@ -950,7 +942,7 @@ void Manager::saveConfiguration()
     {
         // store aggregations
 
-        KConfigGroup conf(MessageListSettings::self()->config(), "MessageListView::Aggregations");
+        KConfigGroup conf(MessageListSettings::self()->config(), QStringLiteral("MessageListView::Aggregations"));
         // conf.clear();
 
         conf.writeEntry("Count", mAggregations.count());
@@ -966,7 +958,7 @@ void Manager::saveConfiguration()
     {
         // store themes
 
-        KConfigGroup conf(MessageListSettings::self()->config(), "MessageListView::Themes");
+        KConfigGroup conf(MessageListSettings::self()->config(), QStringLiteral("MessageListView::Themes"));
         // conf.clear();
 
         conf.writeEntry("Count", mThemes.count());
@@ -981,3 +973,5 @@ void Manager::saveConfiguration()
 
     MessageListSettings::self()->config()->sync();
 }
+
+#include "moc_manager.cpp"
