@@ -654,7 +654,7 @@ TagCache::TagCache()
     , mMonitor(new Akonadi::Monitor(this))
 {
     mCache.setMaxCost(100);
-    mMonitor->setObjectName(QStringLiteral("MessageListTagCacheMonitor"));
+    mMonitor->setObjectName(QLatin1StringView("MessageListTagCacheMonitor"));
     mMonitor->setTypeMonitored(Akonadi::Monitor::Tags);
     mMonitor->tagFetchScope().fetchAttribute<Akonadi::TagAttribute>();
     connect(mMonitor, &Akonadi::Monitor::tagAdded, this, &TagCache::onTagAdded);
