@@ -12,7 +12,6 @@
 #include <QHash>
 #include <QList>
 #include <QMultiHash>
-#include <QVector>
 
 #include <core/enums.h>
 
@@ -109,7 +108,7 @@ public:
      * Returns true if the view is currently loading, that is
      * it's in the first (possibly lengthy) job batch after attaching to a StorageModel.
      */
-    Q_REQUIRED_RESULT bool isLoading() const;
+    [[nodiscard]] bool isLoading() const;
 
     /**
      * Returns the message item that is at the _current_ storage row index
@@ -166,7 +165,7 @@ public:
      * while manipulating the view) so be sure to call deletePersistentSet()
      * when you no longer need it.
      */
-    Q_REQUIRED_RESULT MessageItemSetReference createPersistentSet(const QVector<MessageItem *> &items);
+    [[nodiscard]] MessageItemSetReference createPersistentSet(const QList<MessageItem *> &items);
 
     /**
      * Returns the list of MessageItems that are still existing in the
@@ -175,7 +174,7 @@ public:
      * but may contain less (even 0) if these MessageItem object were removed
      * from the view for some reason.
      */
-    Q_REQUIRED_RESULT QList<MessageItem *> persistentSetCurrentMessageItemList(MessageItemSetReference ref);
+    [[nodiscard]] QList<MessageItem *> persistentSetCurrentMessageItemList(MessageItemSetReference ref);
 
     /**
      * Deletes the persistent set pointed by the specified reference.
@@ -210,4 +209,3 @@ private:
 };
 } // namespace Core
 } // namespace MessageList
-
