@@ -47,7 +47,7 @@ public:
         delete mTheme;
     }
 
-    Q_REQUIRED_RESULT Core::Theme *theme() const
+    [[nodiscard]] Core::Theme *theme() const
     {
         return mTheme;
     }
@@ -71,7 +71,7 @@ public:
 
 public:
     // need a larger but shorter QListWidget
-    Q_REQUIRED_RESULT QSize sizeHint() const override
+    [[nodiscard]] QSize sizeHint() const override
     {
         return {450, 128};
     }
@@ -107,6 +107,9 @@ ConfigureThemesDialog::ConfigureThemesDialog(QWidget *parent)
     d->mThemeList->setSortingEnabled(true);
     g->addWidget(d->mThemeList, 0, 0, 7, 1);
 
+    connect(d->mThemeList, &ThemeListWidget::currentItemChanged, this, [this](QListWidgetItem *item) {
+        d->themeListItemClicked(item);
+    });
     connect(d->mThemeList, &ThemeListWidget::itemClicked, this, [this](QListWidgetItem *item) {
         d->themeListItemClicked(item);
     });
@@ -205,7 +208,7 @@ void ConfigureThemesDialog::ConfigureThemesDialogPrivate::okButtonClicked()
 
     Manager::instance()->themesConfigurationCompleted();
     Q_EMIT q->okClicked();
-    q->close(); // this will delete too
+    q->accept(); // this will delete too
 }
 
 void ConfigureThemesDialog::ConfigureThemesDialogPrivate::commitEditor()
@@ -356,6 +359,7 @@ void ConfigureThemesDialog::ConfigureThemesDialogPrivate::newThemeButtonClicked(
     emptyTheme.addColumn(col);
     auto item = new ThemeListWidgetItem(mThemeList, emptyTheme);
 
+    mThemeList->clearSelection();
     mThemeList->setCurrentItem(item);
     Core::Theme *theme = item->theme();
     if (theme) {
@@ -402,8 +406,9 @@ void ConfigureThemesDialog::ConfigureThemesDialogPrivate::deleteThemeButtonClick
         return;
     }
     const QString question = list.count() > 1 ? i18n("Do you want to delete selected themes?") : i18n("Do you want to delete \"%1\"?", list.first()->text());
-    const int answer = KMessageBox::questionYesNo(q, question, i18nc("@title:window", "Delete Theme"), KStandardGuiItem::del(), KStandardGuiItem::cancel());
-    if (answer == KMessageBox::Yes) {
+    const int answer =
+        KMessageBox::questionTwoActions(q, question, i18nc("@title:window", "Delete Theme"), KStandardGuiItem::del(), KStandardGuiItem::cancel());
+    if (answer == KMessageBox::ButtonCode::PrimaryAction) {
         mEditor->editTheme(nullptr); // forget it
         for (QListWidgetItem *it : list) {
             auto item = dynamic_cast<ThemeListWidgetItem *>(it);
